"""
Conference Actions
"""

from datetime import datetime


class Conference:
    def __init__(self):
        return

    def year(self):
        """
        Get Current Year
        """
        today = datetime.today()
        return today.year

    def location(self, year=None):
        if not year:
            year = self.year()
        return self.__get_current_location(year)

    def cfp(self, year=None):
        if not year:
            year = self.year()
        return self.__get_cfp_status(year)

    def __get_current_location(self, year):
        # TODO: get location data from year wise yaml file
        location = "Anywhere on Earth"
        return location

    def __get_cfp_status(self, year):
        # TODO: get cfp state based on year
        return f"Find more about Call For Proposals at: https://in.pycon.org/cfp/{year}/proposals/"



#!/usr/bin/env python3
"""
PyCon India CLI Tool
"""

import click
from .conference import Conference
from . import __version__, year, location, cfp


@click.group(invoke_without_command=True)
@click.version_option(version=__version__, prog_name="pyconindia")
@click.pass_context
def cli(ctx):
    """PyCon India - The largest gathering of Pythonistas in India"""
    if ctx.invoked_subcommand is None:
        click.echo("🐍 Welcome to PyCon India CLI!")
        click.echo(f"📅 Year: {year}")
        click.echo(f"📍 Location: {location}")
        click.echo(f"📝 CFP: {cfp}")
        click.echo("\nUse --help to see available commands.")


@cli.command()
@click.option('--year', '-y', type=int, help='Specific year to query')
def info(year):
    """Show conference information"""
    conf = Conference()
    current_year = year or conf.year()
    
    click.echo(f"🐍 PyCon India {current_year}")
    click.echo(f"📅 Year: {current_year}")
    click.echo(f"📍 Location: {conf.location(current_year)}")
    click.echo(f"📝 CFP: {conf.cfp(current_year)}")


@cli.command()
@click.option('--year', '-y', type=int, help='Specific year to query')
def location_cmd(year):
    """Get conference location"""
    conf = Conference()
    result = conf.location(year)
    click.echo(f"📍 {result}")


@cli.command()
@click.option('--year', '-y', type=int, help='Specific year to query')
def cfp_cmd(year):
    """Get Call For Proposals information"""
    conf = Conference()
    result = conf.cfp(year)
    click.echo(f"📝 {result}")


@cli.command()
def year_cmd():
    """Get current year"""
    conf = Conference()
    click.echo(f"📅 {conf.year()}")


@cli.command()
def version():
    """Show version information"""
    click.echo(f"pyconindia v{__version__}")


if __name__ == '__main__':
    cli()
